baseflow_ChapmanMaxwell: compute a baseflow time series using the Chapman & Maxwell...

Description Usage Arguments Value References

View source: R/RcppExports.R

Description

This function compute baseflow time series using the algorithm of Chapman and Maxwell (1996)

Usage

1

Arguments

Q

numeric vector. Streamflow vector.

k

float. parameter.

Value

Returns a baseflow time series.

References

T. G. Chapman and A. I. Maxwell, “Baseflow separation - comparison of numerical methods with tracer experiments,” Hobart, Tasmania, 1996.


IvanHeriver/hsa-R-package documentation built on Dec. 17, 2021, 11:32 p.m.