Description Usage Arguments Value See Also
View source: R/flow_duration_curve.R
Given streamflow exceedance probability values (probs) compute the
corresponding streamflow values/percentiles.
1 | fdc_percentiles(Q, probs = c(0.1, 0.9))
|
Q |
numeric vector. Streamflow values. |
probs |
numeric vector containing the exceedance probabilities for the streamflow percentiles to compute. |
A numeric vector of the same length as probs containing the
streamflow percentiles corresponding to the exceedance probabilities
specified with argument probs.
fdc_slope and fdc_slope_percentiles
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.