Description Usage Arguments Details Value References See Also
Given cumulative regime curve of precipitation Pcum and streamflow
Qcum, the inflexions points of the streamflow regime curve returned
by the function mct_inflexionpoints(), this function compute the
one or two snow storage estimates depending on the method used (see details).
1 2 3 4 5 6 7 8 9 |
Pcum |
numeric vector. Cumulative precipitation regime curve. |
Qcum |
numeric vector. Cumulative streamflow regime curve. |
inflexion_points |
numeric vector. A length 2 numeric vector containing
the two inflexion points of the cumulative streamflow regime curve (see
|
use_tangentes |
logical. Should the methodology of Schaefli (2016) be used to compute two snow estimates (see details). |
fixed_intercept |
logical. Should a fixed intercept at (0, 0) be used in the linear regression (see details). |
return_tangents |
logical. Should the tangents values be returned as well. |
period. |
numeric vector. A length 2 numeric vector defining the period
to use to perform the linear regression on |
If use_tangentes is FALSE, the snow storage estimate is simply the
difference Pcum[inflexion_points[1L]] - Qcum[inflexion_points[1L]].
If use_tangentes is TRUE, a linear regression is performed on
Pcum to retrieve the average slope in the period defined by period.
If fixed_intercept is TRUE, a fixed intercept at (0, 0) is used
in the linear regression. If use_tangentes is TRUE, two snow estimates
are computed: (1) from the accumulation period (Sa) and (2) from the
metling period (Sm). For details see Schaefli (2016)
There are three cases:
use_tangentes is FALSE: a single numeric value corresponding to one
storage estiamte.
use_tangentes is TRUE and return_tangents is FALSE: a length 2
numeric vector is returned containing 2 snow storage estimates: (1) from the
accumulation period (Sa) and (2) from the metling period (Sm).
use_tangentes is TRUE and return_tangents is TRUE: a list is
returned containing the the two snow storage estimates (S), the slope of resulting
from the linear regression over Pcum (P_slp), the intercept and slope of the
the two tangents to streamflow at inflexion point 1 (Qa_slp) and inflexion point 2
(Qm_slp). These last two components are length 2 numeric vectors.
B. Schaefli, “Snow hydrology signatures for model identification within a limits-of-acceptability approach”, Hydrological Processes, vol. 30, no. 22, Art. no. 22, Aug. 2016, doi: 10.1002/hyp.10972.
mct_snowstorage
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.